@@ -49,7 +49,7 @@ void Bigram::reset(){
     }
 }
 
-#if 0
+
 /* Use ProtoHashDB for load_db/save_db methods. */
 bool Bigram::load_db(const char * dbfile){
     reset();
@@ -94,7 +94,6 @@ bool Bigram::save_db(const char * dbfile){
 
     return true;
 }
-#endif
 
 bool Bigram::attach(const char * dbfile, guint32 flags){
     reset();
