@@ -4,19 +4,18 @@
  *  
  *  Copyright (C) 2011 Peng Wu <alexepico@gmail.com>
  *  
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
- * 
+ *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
- *  
+ *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -26,15 +25,15 @@
 #include <stdio.h>
 #include <string.h>
 #include "stl_lite.h"
-#include "pinyin_phrase2.h"
+#include "pinyin_phrase3.h"
 #include "pinyin_custom2.h"
 #include "chewing_key.h"
 #include "pinyin_parser_table.h"
 #include "double_pinyin_table.h"
-#include "zhuyin_table.h"
+#include "phonetic_key_matrix.h"
 
 
-using namespace pinyin;
+namespace pinyin{
 
 static bool check_pinyin_options(pinyin_option_t options, const pinyin_index_item_t * item) {
     guint32 flags = item->m_flags;
@@ -301,29 +300,6 @@ int FullPinyinParser2::parse (pinyin_option_t options, ChewingKeyVector & keys,
                     value.m_num_keys == nextstep->m_num_keys) {
 
 #if 0
-                    /* prefer the complete pinyin with shengmu
-                     * over without shengmu,
-                     * ex: "kaneiji" -> "ka'nei'ji".
-                     */
-                    if ((value.m_key.m_initial != CHEWING_ZERO_INITIAL &&
-                         !(value.m_key.m_middle == CHEWING_ZERO_MIDDLE &&
-                           value.m_key.m_final == CHEWING_ZERO_FINAL)) &&
-                        nextstep->m_key.m_initial == CHEWING_ZERO_INITIAL)
-                        *nextstep = value;
-
-                    /* prefer the complete pinyin 'er'
-                     * over the in-complete pinyin 'r',
-                     * ex: "xierqi" -> "xi'er'qi."
-                     */
-                    if ((value.m_key.m_initial == CHEWING_ZERO_INITIAL &&
-                        value.m_key.m_middle == CHEWING_ZERO_MIDDLE &&
-                        value.m_key.m_final == CHEWING_ER) &&
-                        (nextstep->m_key.m_initial == CHEWING_R &&
-                         nextstep->m_key.m_middle == CHEWING_ZERO_MIDDLE &&
-                         nextstep->m_key.m_final == CHEWING_ZERO_FINAL))
-                        *nextstep = value;
-#endif
-
                     /* prefer the 'a' at the end of clause,
                      * ex: "zheyanga$" -> "zhe'yang'a$".
                      */
@@ -334,6 +310,7 @@ int FullPinyinParser2::parse (pinyin_option_t options, ChewingKeyVector & keys,
                          value.m_key.m_middle == CHEWING_ZERO_MIDDLE &&
                          value.m_key.m_final == CHEWING_A))
                         *nextstep = value;
+#endif
                 }
             }
         }
@@ -342,10 +319,12 @@ int FullPinyinParser2::parse (pinyin_option_t options, ChewingKeyVector & keys,
     /* final step for back tracing. */
     gint16 parsed_len = final_step(step_len, keys, key_rests);
 
+#if 0
     /* post processing for re-split table. */
     if (options & USE_RESPLIT_TABLE) {
         post_process2(options, keys, key_rests, str, len);
     }
+#endif
 
     g_free(input);
     return parsed_len;
@@ -408,191 +387,6 @@ bool FullPinyinParser2::set_scheme(FullPinyinScheme scheme){
     return true;
 }
 
-bool FullPinyinParser2::post_process2(pinyin_option_t options,
-                                      ChewingKeyVector & keys,
-                                      ChewingKeyRestVector & key_rests,
-                                      const char * str,
-                                      int len) const {
-    int i;
-    assert(keys->len == key_rests->len);
-    gint num_keys = keys->len;
-
-    ChewingKey * cur_key = NULL, * next_key = NULL;
-    ChewingKeyRest * cur_rest = NULL, * next_rest = NULL;
-    guint16 next_tone = CHEWING_ZERO_TONE;
-
-    for (i = 0; i < num_keys - 1; ++i) {
-        cur_rest = &g_array_index(key_rests, ChewingKeyRest, i);
-        next_rest = &g_array_index(key_rests, ChewingKeyRest, i + 1);
-
-        /* some "'" here */
-        if (cur_rest->m_raw_end != next_rest->m_raw_begin)
-            continue;
-
-        cur_key = &g_array_index(keys, ChewingKey, i);
-        next_key = &g_array_index(keys, ChewingKey, i + 1);
-
-        /* some tone here */
-        if (CHEWING_ZERO_TONE != cur_key->m_tone)
-            continue;
-
-        /* back up tone */
-        if (options & USE_TONE) {
-            next_tone = next_key->m_tone;
-            if (CHEWING_ZERO_TONE != next_tone) {
-                next_key->m_tone = CHEWING_ZERO_TONE;
-                next_rest->m_raw_end --;
-            }
-        }
-
-        /* lookup re-split table */
-        const resplit_table_item_t * item = NULL;
-
-        item = retrieve_resplit_item_by_original_pinyins
-            (options, cur_key, cur_rest, next_key, next_rest, str, len);
-
-        if (item) {
-            /* no ops */
-            if (item->m_orig_freq >= item->m_new_freq)
-                continue;
-
-            /* do re-split */
-            const char * onepinyin = str + cur_rest->m_raw_begin;
-            size_t len = strlen(item->m_new_keys[0]);
-
-            assert(parse_one_key(options, *cur_key, onepinyin, len));
-            cur_rest->m_raw_end = cur_rest->m_raw_begin + len;
-
-            next_rest->m_raw_begin = cur_rest->m_raw_end;
-            onepinyin = str + next_rest->m_raw_begin;
-            len = strlen(item->m_new_keys[1]);
-
-            assert(parse_one_key(options, *next_key, onepinyin, len));
-        }
-
-        /* restore tones */
-        if (options & USE_TONE) {
-            if (CHEWING_ZERO_TONE != next_tone) {
-                next_key->m_tone = next_tone;
-                next_rest->m_raw_end ++;
-            }
-        }
-    }
-
-    return true;
-}
-
-const divided_table_item_t * FullPinyinParser2::retrieve_divided_item
-(pinyin_option_t options, ChewingKey * key, ChewingKeyRest * rest,
- const char * str, int len) const {
-
-    /* lookup divided table */
-    size_t k;
-    const divided_table_item_t * item = NULL;
-    for (k = 0; k < G_N_ELEMENTS(divided_table); ++k) {
-        item = divided_table + k;
-
-        const char * onepinyin = str + rest->m_raw_begin;
-        size_t len = strlen(item->m_orig_key);
-
-        if (rest->length() != len)
-            continue;
-
-        if (0 == strncmp(onepinyin, item->m_orig_key, len))
-            break;
-    }
-
-    /* found the match */
-    if (k < G_N_ELEMENTS(divided_table)) {
-        /* do divided */
-        item = divided_table + k;
-        return item;
-    }
-
-    return NULL;
-}
-
-
-const resplit_table_item_t * FullPinyinParser2::retrieve_resplit_item_by_original_pinyins
-(pinyin_option_t options,
- ChewingKey * cur_key, ChewingKeyRest * cur_rest,
- ChewingKey * next_key, ChewingKeyRest * next_rest,
- const char * str, int len) const{
-    /* lookup re-split table */
-    size_t k;
-    const resplit_table_item_t * item = NULL;
-
-    for (k = 0; k < G_N_ELEMENTS(resplit_table); ++k) {
-        item = resplit_table + k;
-
-        const char * onepinyin = str + cur_rest->m_raw_begin;
-        size_t len = strlen(item->m_orig_keys[0]);
-
-        if (cur_rest->length() != len)
-            continue;
-
-        if (0 != strncmp(onepinyin, item->m_orig_keys[0], len))
-            continue;
-
-        onepinyin = str + next_rest->m_raw_begin;
-        len = strlen(item->m_orig_keys[1]);
-
-        if (next_rest->length() != len)
-            continue;
-
-        if (0 == strncmp(onepinyin, item->m_orig_keys[1], len))
-            break;
-    }
-
-    /* found the match */
-    if (k < G_N_ELEMENTS(resplit_table)) {
-        item = resplit_table + k;
-        return item;
-    }
-
-    return NULL;
-}
-
-const resplit_table_item_t * FullPinyinParser2::retrieve_resplit_item_by_resplit_pinyins
-(pinyin_option_t options,
- ChewingKey * cur_key, ChewingKeyRest * cur_rest,
- ChewingKey * next_key, ChewingKeyRest * next_rest,
- const char * str, int len) const {
-    /* lookup divide table */
-    size_t k;
-    const resplit_table_item_t * item = NULL;
-
-    for (k = 0; k < G_N_ELEMENTS(resplit_table); ++k) {
-        item = resplit_table + k;
-
-        const char * onepinyin = str + cur_rest->m_raw_begin;
-        size_t len = strlen(item->m_new_keys[0]);
-
-        if (cur_rest->length() != len)
-            continue;
-
-        if (0 != strncmp(onepinyin, item->m_new_keys[0], len))
-            continue;
-
-        onepinyin = str + next_rest->m_raw_begin;
-        len = strlen(item->m_new_keys[1]);
-
-        if (next_rest->length() != len)
-            continue;
-
-        if (0 == strncmp(onepinyin, item->m_new_keys[1], len))
-            break;
-    }
-
-    /* found the match */
-    if (k < G_N_ELEMENTS(resplit_table)) {
-        item = resplit_table + k;
-        return item;
-    }
-
-    return NULL;
-}
-
 #define IS_KEY(x)   (('a' <= x && x <= 'z') || x == ';')
 
 bool DoublePinyinParser2::parse_one_key(pinyin_option_t options,
@@ -903,3 +697,5 @@ int PinyinDirectParser2::parse(pinyin_option_t options,
 
     return parsed_len;
 }
+
+}
