@@ -4,21 +4,24 @@
  *  
  *  Copyright (C) 2010 Peng Wu
  *  
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
- * 
+ *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
- *  
+ *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <stdio.h>
 #include <locale.h>
 #include <glib.h>
@@ -53,10 +56,10 @@ static size_t len = 0;
 
 bool parse_headline();
 
-bool parse_unigram(FILE * input, PhraseLargeTable2 * phrase_table,
+bool parse_unigram(FILE * input, PhraseLargeTable3 * phrase_table,
                    FacadePhraseIndex * phrase_index);
 
-bool parse_bigram(FILE * input, PhraseLargeTable2 * phrase_table,
+bool parse_bigram(FILE * input, PhraseLargeTable3 * phrase_table,
                   FacadePhraseIndex * phrase_index,
                   Bigram * bigram);
 
@@ -91,7 +94,7 @@ bool parse_headline(){
     return true;
 }
 
-bool parse_body(FILE * input, PhraseLargeTable2 * phrase_table,
+bool parse_body(FILE * input, PhraseLargeTable3 * phrase_table,
                 FacadePhraseIndex * phrase_index,
                 Bigram * bigram){
     taglib_push_state();
@@ -124,7 +127,7 @@ bool parse_body(FILE * input, PhraseLargeTable2 * phrase_table,
     return true;
 }
 
-bool parse_unigram(FILE * input, PhraseLargeTable2 * phrase_table,
+bool parse_unigram(FILE * input, PhraseLargeTable3 * phrase_table,
                    FacadePhraseIndex * phrase_index){
     taglib_push_state();
 
@@ -158,7 +161,7 @@ bool parse_unigram(FILE * input, PhraseLargeTable2 * phrase_table,
     return true;
 }
 
-bool parse_bigram(FILE * input, PhraseLargeTable2 * phrase_table,
+bool parse_bigram(FILE * input, PhraseLargeTable3 * phrase_table,
                   FacadePhraseIndex * phrase_index,
                   Bigram * bigram){
     taglib_push_state();
@@ -260,15 +263,13 @@ int main(int argc, char * argv[]){
     }
     g_free(filename);
 
-    PhraseLargeTable2 phrase_table;
+    PhraseLargeTable3 phrase_table;
 
-    MemoryChunk * chunk = new MemoryChunk;
-    retval = chunk->load(SYSTEM_PHRASE_INDEX);
+    retval = phrase_table.attach(SYSTEM_PHRASE_INDEX, ATTACH_READONLY);
     if (!retval) {
-        fprintf(stderr, "open phrase_index.bin failed!\n");
+        fprintf(stderr, "open %s failed!\n", SYSTEM_PHRASE_INDEX);
         exit(ENOENT);
     }
-    phrase_table.load(chunk);
 
     FacadePhraseIndex phrase_index;
 
